@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ PreferredLineEditWidget::PreferredLineEditWidget(QWidget *parent)
     connect(mPreferredAction, &QAction::triggered, this, &PreferredLineEditWidget::slotPreferredStatusChanged);
 }
 
-PreferredLineEditWidget::~PreferredLineEditWidget()
-{
-}
+PreferredLineEditWidget::~PreferredLineEditWidget() = default;
 
 void PreferredLineEditWidget::slotPreferredStatusChanged()
 {
